#XfceNotifyWindow {
    background-color: #f2f1f1;
    color: #686868;
    border: 1px solid shade(#f2f1f1, 0.6);
}

#XfceNotifyWindow button {
    background-image: none;
    background-color: #f2f1f1;
    color: shade(#f2f1f1, 0.4);
    border-color: shade(#f2f1f1, 0.6);
    border-radius: 3px;
}

#XfceNotifyWindow button:hover {
    background-color: shade(#f2f1f1, 0.9);
}

#XfceNotifyWindow button:active {
    background-color: shade(#f2f1f1, 0.8);
}

#XfceNotifyWindow label#summary {
    font-weight: bold;
}

#XfceNotifyWindow progressbar {
    min-height: 6px;
    border-radius: 3px;
}

#XfceNotifyWindow progressbar progress {
    background-image: none;
    background-color: #686868;
    border: none;
    box-shadow: none;
}

#XfceNotifyWindow progressbar trough {
    background-image: linear-gradient(to bottom,
                                      shade(#f2f1f1, 0.65),
                                      shade(#f2f1f1, 1.25)
                                      );
    border: 1px solid shade(#f2f1f1, 0.2);
    border-radius: 3px;
    padding: 1px 0;
}
