#XfceNotifyWindow {
    background-color: shade(#686868, 0.3);
    color: #fcfcfc;
    border: 1px solid shade(#686868, 0.6);
    border-radius: 6px;
}

#XfceNotifyWindow button {
    background-image: none;
    background-color: shade(#686868, 0.3);
    color: #fcfcfc;
    border-color: shade(#fcfcfc, 0.35);
    border-radius: 3px;
}

#XfceNotifyWindow button:hover {
    background-color: shade(#686868, 0.4);
    border-color: shade(#fcfcfc, 0.45);
}

#XfceNotifyWindow label#summary {
    font-weight: bold;
}

#XfceNotifyWindow progressbar {
    min-height: 6px;
    border-radius: 3px;
}

#XfceNotifyWindow progressbar progress {
    background-image: none;
    background-color: #fcfcfc;
    border: none;
    box-shadow: none;
}

#XfceNotifyWindow progressbar trough {
    background-image: linear-gradient(to bottom,
                                      shade(#686868, 0.65),
                                      shade(#686868, 1.25)
                                      );
    border: 1px solid shade(#686868, 0.2);
    border-radius: 3px;
    padding: 1px 0;
}
